==> advanced-power-monitor-src_0.5.1-2.tar.gz: advanced-power-monitor-src-0.5.1/src/usr/src/advanced-power-monitor/wrappers/battery/BatteryBME.py <==
'''
Advanced Power Battery Wraper BME
2009(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from Util import Shell
from wrappers.battery.AbstractBattery import AbstractBattery

class BatteryBME(AbstractBattery):

  def pre_init(self):
    self.friendly_name = 'Nokia\'s BME'
    self.dep_packages = ['hald-addon-bme']
    self.interfaces_map = {'BME': ('org.freedesktop.Hal', '/org/freedesktop/Hal/devices/bme', 'org.freedesktop.Hal.Device')}
    self.export_signals = {'battery_charger_is_connected': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'charger_charging_on'},
                           'battery_charger_is_disconnected': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'charger_disconnected'},
                           'battery_is_full': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'battery_full'},
                           'battery_percentage': {'path': '/org/freedesktop/Hal/devices/bme', 'dbus_interface': 'org.freedesktop.Hal.Device', 'signal_name': 'PropertyModified'},
                           'battery_timeleft_info': {'path': '/org/freedesktop/Hal/devices/bme', 'dbus_interface': 'org.freedesktop.Hal.Device', 'signal_name': 'PropertyModified'}
                          }

  def post_init(self):
    self.battery_design = self.interfaces['BME'].GetPropertyInteger(u'battery.reporting.design')
    self.timeleft_idle_const = 15400*60
    self.get_percent('battery', [['battery.reporting.current']])
    self.get_timeleft('battery', [['battery.remaining_time']])
    self.get_status()

#Object path: /org/freedesktop/Hal/devices/bme
#Interface: org.freedesktop.Hal.Device
#Signal: PropertyModified
  def get_percent(self, value, props):
    signals = [str(x[0]) for x in props]
    if 'battery.reporting.current' in signals:
      self.battery_percent = self.percentage(self.interfaces['BME'].GetPropertyInteger(u'battery.reporting.current'), self.battery_design)
    return self.battery_percent

  def get_status(self):
    Shell.run_command_async('/usr/bin/dbus-send --system --type=signal /com/nokia/bme/request com.nokia.bme.request.status_info_req')

  def get_timeleft(self, value, props):
    signals = [str(x[0]) for x in props]
    if 'battery.remaining_time' in signals:
      try:
        self.timeleft_active = int(self.interfaces['BME'].GetPropertyInteger(u'battery.remaining_time'))
      except:
        pass
      self.timeleft_idle = int((self.timeleft_idle_const * self.battery_percent) / 100)
    return [self.timeleft_idle, self.timeleft_active]

==> advanced-power-monitor-src_0.5.1-3.tar.gz: advanced-power-monitor-src-0.5.1/src/usr/src/advanced-power-monitor/wrappers/battery/BatteryBME.py <==
'''
Advanced Power Battery Wraper BME
2009-2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from Util import Shell
from wrappers.battery.AbstractBattery import AbstractBattery

class BatteryBME(AbstractBattery):

  def pre_init(self):
    self.friendly_name = 'Nokia\'s BME'
    self.dep_packages = {'hald-addon-bme': '0.0.4'}
    self.interfaces_map = {'BME': ('org.freedesktop.Hal', '/org/freedesktop/Hal/devices/bme', 'org.freedesktop.Hal.Device')}
    self.export_signals = {'battery_charger_is_connected': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'charger_charging_on'},
                           'battery_charger_is_disconnected': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'charger_disconnected'},
                           'battery_is_full': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'battery_full'},
                           'battery_percentage': {'path': '/org/freedesktop/Hal/devices/bme', 'dbus_interface': 'org.freedesktop.Hal.Device', 'signal_name': 'PropertyModified'},
                           'battery_timeleft_info': {'path': '/org/freedesktop/Hal/devices/bme', 'dbus_interface': 'org.freedesktop.Hal.Device', 'signal_name': 'PropertyModified'}
                          }

  def post_init(self):
    self.battery_design = self.interfaces['BME'].GetPropertyInteger(u'battery.reporting.design')
    self.timeleft_idle_const = 15400*60
    self.get_percent('battery', [['battery.reporting.current']])
    self.get_timeleft('battery', [['battery.remaining_time']])
    self.get_status()

#Object path: /org/freedesktop/Hal/devices/bme
#Interface: org.freedesktop.Hal.Device
#Signal: PropertyModified
  def get_percent(self, value, props):
    signals = [str(x[0]) for x in props]
    if 'battery.reporting.current' in signals:
      self.battery_percent = self.percentage(self.interfaces['BME'].GetPropertyInteger(u'battery.reporting.current'), self.battery_design)
    return self.battery_percent

  def get_status(self):
    Shell.run_command_async('/usr/bin/dbus-send --system --type=signal /com/nokia/bme/request com.nokia.bme.request.status_info_req')

  def get_timeleft(self, value, props):
    signals = [str(x[0]) for x in props]
    if 'battery.remaining_time' in signals:
      try:
        self.timeleft_active = int(self.interfaces['BME'].GetPropertyInteger(u'battery.remaining_time'))
      except:
        pass
      self.timeleft_idle = int((self.timeleft_idle_const * self.battery_percent) / 100)
    return [self.timeleft_idle, self.timeleft_active]
